@@ -19,10 +19,10 @@ from pymgrit.core.grid_transfer_copy import GridTransferCopy
 
 class Mgrit:
     """
-    Set up an MGRIT solver, given an array of problems (and an array of grid transfers)
+    Sets up the MGRIT solver for a given problem structure
 
-    The problems are assumed to have a  of constant dimension and the spacetime
-    matrix stencil solved is [-Phi  I].
+    It is assumed that the problems have a constant dimension
+    and the solved space-time matrix stencil is [-Phi I].
     """
 
     def __init__(self, problem: List[Application], transfer: List[GridTransfer] = None,
@@ -56,7 +56,7 @@ class Mgrit:
         logging.basicConfig(format='%(levelname)s - %(asctime)s - %(message)s', datefmt='%d-%m-%y %H:%M:%S',
                             level=logging_lvl, stream=sys.stdout)
 
-        if transfer == None:
+        if transfer is None:
             transfer = [GridTransferCopy() for i in range(len(problem) - 1)]
 
         if len(problem) != (len(transfer) + 1):
@@ -186,8 +186,9 @@ class Mgrit:
 
     def log_info(self, message: str) -> None:
         """
-        Writes the message to the logger. Only one processor
-        :param message:
+        Writes a transferred message to the logger.
+        Only one process
+        :param message: Message
         """
         if self.comm_time_rank == 0:
             if self.spatial_parallel:
@@ -201,8 +202,8 @@ class Mgrit:
 
     def create_u(self, lvl: int) -> None:
         """
-        Create the solution vector.
-        :param lvl:
+        Creates the solution vectors for each point in time on the process for a given level
+        :param lvl: MGRIT level
         """
         self.u.append([object] * self.block_size_this_lvl[lvl])
         for i in range(len(self.u[lvl])):
@@ -219,11 +220,10 @@ class Mgrit:
     def iteration(self, lvl: int, cycle_type: str, iteration: int, first_f: bool) -> None:
         """
         Performs one MGRIT iteration
-        :return:
-        :param lvl: the corresponding MGRIT level
-        :param cycle_type:
-        :param iteration:
-        :param first_f:
+        :param lvl: MGRIT level
+        :param cycle_type: Cycle type
+        :param iteration: Number of the current iteration
+        :param first_f: F-relaxation at the beginning
         :return:
         """
         if lvl == self.lvl_max - 1:
@@ -254,8 +254,11 @@ class Mgrit:
 
     def f_relax(self, lvl: int) -> None:
         """
-        Performs a F-relaxation
-        :param lvl: the corresponding MGRIT level
+        Performs a F-relaxation:
+        The so-called F-relaxation performs a relaxation on F-points
+        and propagates the solution from one C-point to all F-points
+        up to the next C-point.
+        :param lvl: MGRIT level
         """
         runtime_f = time.time()
         tmp_send = False
@@ -283,8 +286,10 @@ class Mgrit:
 
     def c_relax(self, lvl: int) -> None:
         """
-        Perfoms a C relaxation
-        :param lvl: the corresponding MGRIT level
+        Performs a C-relaxation:
+        The so-called C-relaxation performs a relaxation on C-points
+        and propagates the solution to a C-point.
+        :param lvl: MGRIT level
         """
         runtime_c = time.time()
         if self.index_local_c[lvl].size > 0:
@@ -302,19 +307,18 @@ class Mgrit:
 
     def convergence_criterion(self, iteration: int) -> None:
         """
-        compute pace-time residual
-        solve A(u) = g with
+        Computes the space-time residual by solving A(u) = g with
              |   I                |
          A = | -Phi   I           |
              |       ...   ...    |
              |            -Phi  I |
         where Phi propagates u_{i-1} from t = t_{i-1} to t = t_i:
-           u_i = Phi(u_{i-1}) (including forcing from RHS of PDE)
+          u_i = Phi(u_{i-1}) (including forcing from RHS of PDE)
         and with
-           g = (u_0 0 ... 0)^T
+          g = (u_0 0 ... 0)^T
         The residual can be computed by
-         r_i = Phi(u_{i-1}) - u_i, i = 1, .... nt,
-         r_0 = 0
+          r_i = Phi(u_{i-1}) - u_i, i = 1, .... nt,
+          r_0 = 0
         """
         runtime_conv = time.time()
         r_norm = []
@@ -351,8 +355,8 @@ class Mgrit:
 
     def forward_solve(self, lvl: int) -> None:
         """
-        Solve the problem via time stepping on coarsest grid
-            :param lvl: the corresponding MGRIT level
+        Solves the problem directly with time stepping
+            :param lvl: MGRIT level
         """
 
         runtime_fs = time.time()
@@ -371,7 +375,7 @@ class Mgrit:
 
     def get_c_point(self, lvl: int) -> Application:
         """
-        Exchange of the first/last C-point between two processes
+        Exchanges the first/last C-point between two processes
         :param lvl: the corresponding MGRIT level
         """
         rank = self.comm_time_rank
@@ -392,7 +396,7 @@ class Mgrit:
 
     def fas_residual(self, lvl: int) -> None:
         """
-        Inject the fine grid approximation and its residual to the coarse grid
+        Injects the fine grid approximation and its residual to the coarse grid
         :param lvl: the corresponding MGRIT level
         """
         runtime_fas_res = time.time()
@@ -444,7 +448,8 @@ class Mgrit:
 
     def nested_iteration(self) -> None:
         """
-        Generate initial approximation by the computation and interpolation of approximations on coarser grids
+        Generates an initial approximation by solving the problem on the coarsest grid and interpolating
+        of the approximation to the finest level.
         """
         self.forward_solve(self.lvl_max - 1)
 
@@ -480,8 +485,9 @@ class Mgrit:
 
     def f_exchange(self, lvl: int) -> None:
         """
-        Point exchange if the first point is a C-points. Typically, after an F-point update
-        :param lvl: the corresponding MGRIT level
+        Point exchange if the first point of a process is a C-points.
+        Typically, after an F-point update
+        :param lvl: MGRIT level
         """
         runtime_ex = time.time()
         rank = self.comm_time_rank
@@ -493,8 +499,9 @@ class Mgrit:
 
     def c_exchange(self, lvl: int) -> None:
         """
-        Point exchange if the first point is a F-points. Typically, after an C-point update
-        :param lvl: the corresponding MGRIT level
+        Point exchange if the first point of a process is a F-points.
+        Typically, after an C-point update
+        :param lvl: MGRIT level
         """
         runtime_ex = time.time()
         rank = self.comm_time_rank
@@ -506,8 +513,8 @@ class Mgrit:
 
     def solve(self) -> dict:
         """
-        Main function for solving the problem. Performs MGRIT iterations until a stopping criteria
-        is reached or the maximum number of iterations
+        Main function for solving the problem.
+        Performs MGRIT iterations until a stopping criteria is reached or the maximum number of iterations
         :return:
         """
         self.comm_time.barrier()
@@ -553,8 +560,8 @@ class Mgrit:
 
     def error_correction(self, lvl: int) -> None:
         """
-        Compute the coarse grid error approximation
-        :param lvl: the corresponding MGRIT level
+        Computes the error approximation and updates the finer level
+        :param lvl: MGRIT level
         """
         for i in range(len(self.index_local_c[lvl])):
             error = self.interpolation[lvl](self.u[lvl + 1][self.index_local[lvl][i]] - self.v[lvl + 1][
@@ -564,45 +571,45 @@ class Mgrit:
 
     def split_points(self, length: int, size: int, rank: int) -> Tuple[int, int]:
         """
-        Split points evenly in size parts and compute the first point and block size of the process interval
+        Splits points evenly in "size" parts and computes the first point and block size of the process interval
         :param length: Number of points
         :param size: Number of processes
         :param rank: Rank
-        :return:
+        :return: Block size and first point
         """
-        block_size = self.split_into(number_points=length, procs=size)[rank]
+        block_size = self.split_into(number_points=length, number_processes=size)[rank]
 
         first_i = 0
         if block_size > 0:
             for i in range(size):
                 if i == rank:
                     break
-                first_i += self.split_into(length, size)[i]
+                first_i += self.split_into(number_points=length, number_processes=size)[i]
         return block_size, first_i
 
     @staticmethod
-    def split_into(number_points: int, procs: int) -> np.ndarray:
+    def split_into(number_points: int, number_processes: int) -> np.ndarray:
         """
         Split points
-        :param number_points:
-        :param procs:
+        :param number_points: Number of points
+        :param number_processes: Number of processes
         :return:
         """
-        return np.array([int(number_points / procs + 1)] * (number_points % procs) + [int(number_points / procs)] *
-                        (procs - number_points % procs))
+        return np.array([int(number_points / number_processes + 1)] * (number_points % number_processes) +
+                        [int(number_points / number_processes)] * (number_processes - number_points % number_processes))
 
     def setup_points(self, lvl: int) -> None:
         """
         Computes grid information per process
-        :param lvl: the corresponding MGRIT level
+        :param lvl: MGRIT level
         :return:
         """
         points_time = np.size(self.problem[lvl].t)
         all_pts = np.array(range(0, points_time))
 
-        # Compute all pts per process
-        # First level by splitting of points
-        # other levels by time depending on first grid
+        # Compute points per process
+        # First level: Dividing the points evenly
+        # Other levels: Depends on the first level
         if lvl == 0:
             block_size_this_lvl, first_i_this_lvl = self.split_points(length=np.size(all_pts),
                                                                       size=self.comm_time_size,
