@@ -7,11 +7,11 @@ Time integration methods:
    Crank-Nicolson
 """
 
+from typing import Callable, Union
 import numpy as np
 from scipy.sparse import diags
 from scipy.sparse import identity
 from scipy.sparse.linalg import spsolve
-from typing import Callable, Union
 
 from pymgrit.core.application import Application
 from pymgrit.core.vector import Vector
@@ -79,7 +79,7 @@ class VectorHeat2D(Vector):
         :rtype: vector object with random values
         """
         tmp = VectorHeat2D(self.nx, self.ny)
-        tmp.set_values(np.random.rand((self.nx, self.ny)))
+        tmp.set_values(np.random.rand(self.nx, self.ny))
         return tmp
 
     def set_values(self, values):
@@ -251,7 +251,7 @@ class Heat2D(Application):
 
     def compute_rhs(self, u_start: np.ndarray, t_start: float, t_stop: float):
         """
-        Right-hand side of spatial system for implicit time integratio nmethods
+        Right-hand side of spatial system for implicit time integration methods
 
         :param u_start: approximate solution for the input time t_start
         :param t_start: time associated with the input approximate solution u_start
@@ -259,14 +259,8 @@ class Heat2D(Application):
         :return: right-hand side of spatial system at each time step in case of implicit time integration
         """
 
-        # Set boundary conditions
         b = np.zeros((self.nx, self.ny))
 
-        b[:, 0] = self.bc_left(self.x)
-        b[:, -1] = self.bc_right(self.x)
-        b[-1, :] = self.bc_bottom(self.y)
-        b[0, :] = self.bc_top(self.y)
-
         if self.theta == 1:
             # BE
             b[1:-1, 1:-1] = u_start[1:-1, 1:-1] + \
@@ -281,7 +275,11 @@ class Heat2D(Application):
                                                                         t=t_stop) + \
                              (1 - self.theta) * (t_stop - t_start) * self.rhs(x=self.x_2d[1:-1], y=self.y_2d[:, 1:-1],
                                                                               t=t_start)
-
+        # Set boundary conditions
+        b[:, 0] = self.bc_left(self.x)
+        b[:, -1] = self.bc_right(self.x)
+        b[-1, :] = self.bc_bottom(self.y)
+        b[0, :] = self.bc_top(self.y)
         return b.flatten()
 
     def step(self, u_start: VectorHeat2D, t_start: float, t_stop: float) -> VectorHeat2D:
